==> worker_manager-2.6.4.tar.gz: lib/src/cancelable.dart <==
import 'dart:async';
import 'dart:ui';

class Cancelable<O> implements Future {
  final Completer<O> _completer;
  final VoidCallback onCancel;

  Cancelable(this._completer, this.onCancel);

  void cancel() {
    onCancel();
    if (!_completer.isCompleted) _completer.completeError(CanceledError());
  }

  @override
  Stream asStream() => _completer.future.asStream();

  @override
  Future catchError(Function onError, {bool Function(Object error) test}) =>
      _completer.future.catchError(onError, test: test);

  @override
  Future<R> then<R>(Function(O value) onValue, {Function onError}) => _completer.future.then(onValue, onError: onError);

//  Cancelable<R> next<R>(Function(O value) onValue, {Function onError}) {
//    final resultCompleter = Completer<O>();
//    _completer.future.then((value) {
//      resultCompleter.complete(value);
//    }, onError: (e){
//      resultCompleter.complete(e);
//    });
//
//
//
//
//
//
//    return Cancelable(resultCompleter, onCancel);
//  }

  @override
  Future timeout(Duration timeLimit, {FutureOr Function() onTimeout}) => _completer.future.timeout(timeLimit);

  @override
  Future whenComplete(FutureOr Function() action) => _completer.future.whenComplete(action);
}

class CanceledError implements Exception {}

//CancelableOperation<R> then<R>(FutureOr<R> Function(T) onValue,
//    {FutureOr<R> Function(Object, StackTrace) onError,
//      FutureOr<R> Function() onCancel,
//      bool propagateCancel = false}) {
//  final completer =
//  CancelableCompleter<R>(onCancel: propagateCancel ? cancel : null);
//
//  valueOrCancellation().then((T result) {
//    if (!completer.isCanceled) {
//      if (isCompleted) {
//        completer.complete(Future.sync(() => onValue(result)));
//      } else if (onCancel != null) {
//        completer.complete(Future.sync(onCancel));
//      } else {
//        completer._cancel();
//      }
//    }
//  }, onError: (error, StackTrace stackTrace) {
//    if (!completer.isCanceled) {
//      if (onError != null) {
//        completer.complete(Future.sync(() => onError(error, stackTrace)));
//      } else {
//        completer.completeError(error, stackTrace);
//      }
//    }
//  });
//  return completer.operation;
//}

==> worker_manager-2.6.6.tar.gz: lib/src/cancelable.dart <==
import 'dart:async';
import 'dart:ui';

class Cancelable<O> implements Future {
  final Completer<O> _completer;
  final VoidCallback onCancel;

  Cancelable(this._completer, this.onCancel);

  void cancel() {
    onCancel();
    if (!_completer.isCompleted) _completer.completeError(CanceledError());
  }

  @override
  Stream asStream() => _completer.future.asStream();

  @override
  Future catchError(Function onError, {bool Function(Object error) test}) =>
      _completer.future.catchError(onError, test: test);

  @override
  Future<R> then<R>(Function(O value) onValue, {Function onError}) => _completer.future.then(onValue, onError: onError);

  Cancelable<O> next(Function(O value) onValue, {Function onError}) {
    final resultCompleter = Completer<O>();
    _completer.future.then((value) {
      try {
        onValue(value);
        resultCompleter.complete(value);
      } catch (e) {
        resultCompleter.completeError(e);
      }
    }, onError: (e) {
      resultCompleter.completeError(e);
    });
    return Cancelable(resultCompleter, onCancel);
  }

  @override
  Future timeout(Duration timeLimit, {FutureOr Function() onTimeout}) => _completer.future.timeout(timeLimit);

  @override
  Future whenComplete(FutureOr Function() action) => _completer.future.whenComplete(action);
}

class CanceledError implements Exception {}

//CancelableOperation<R> then<R>(FutureOr<R> Function(T) onValue,
//    {FutureOr<R> Function(Object, StackTrace) onError,
//      FutureOr<R> Function() onCancel,
//      bool propagateCancel = false}) {
//  final completer =
//  CancelableCompleter<R>(onCancel: propagateCancel ? cancel : null);
//
//  valueOrCancellation().then((T result) {
//    if (!completer.isCanceled) {
//      if (isCompleted) {
//        completer.complete(Future.sync(() => onValue(result)));
//      } else if (onCancel != null) {
//        completer.complete(Future.sync(onCancel));
//      } else {
//        completer._cancel();
//      }
//    }
//  }, onError: (error, StackTrace stackTrace) {
//    if (!completer.isCanceled) {
//      if (onError != null) {
//        completer.complete(Future.sync(() => onError(error, stackTrace)));
//      } else {
//        completer.completeError(error, stackTrace);
//      }
//    }
//  });
//  return completer.operation;
//}
